import time

import jwt
from flask import g, jsonify

from app.configs.config import JWT_SECRET, JWT_EXPIRY
from app.defines import StatesCode

headers = {
    "alg": "HS256",
    "typ": "JWT"
}


def generate_jwt(user_id):
    """
    生成jwt
    :param user_id: 用户id
    :return: jwt
    """
    payload = {
        'user_id': user_id,
        'exp': int(time.time() + JWT_EXPIRY)
    }

    token = jwt.encode(payload, JWT_SECRET, algorithm='HS256', headers=headers)
    return token


def verify_jwt(token):
    """
    检验jwt
    :param token: jwt
    :return: dict: payload
    """

    try:
        payload = jwt.decode(token, JWT_SECRET, algorithms=['HS256'], headers=headers)
    except jwt.DecodeError:
        payload = None

    # except jwt.InvalidSignatureError:
    #     payload = None

    return payload


def login_required(func):
    def wrapper(*args, **kwargs):
        if g.user_id is not None:
            return func(*args, **kwargs)
        else:
            return jsonify(code=StatesCode.UNKNOWN_ERROR, message='无效的token')

    return wrapper
